@@ -25,6 +25,7 @@ INSTALLED_APPS = (
 ROOT_URLCONF = 'django_browserid.tests.urls'
 
 AUTHENTICATION_BACKENDS = (
+    'django.contrib.auth.backends.ModelBackend',
     'django_browserid.auth.BrowserIDBackend',
 )
 
@@ -32,3 +33,5 @@ BROWSERID_CREATE_USER = True
 BROWSERID_USERNAME_ALGO = None
 
 STATIC_URL = 'static/'
+
+BROWSERID_AUDIENCES = ['http://testserver']
